==> react-native-0.57.2.tgz: package/Libraries/Components/AppleTV/TVViewPropTypes.js <==
/**
 * Copyright (c) 2015-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 * @flow
 */

'use strict';
const PropTypes = require('prop-types');

/**
 * Additional View properties for Apple TV
 */
const TVViewPropTypes = {
  /**
   * When set to true, this view will be focusable
   * and navigable using the TV remote.
   */
  isTVSelectable: PropTypes.bool,

  /**
   * May be set to true to force the TV focus engine to move focus to this view.
   */
  hasTVPreferredFocus: PropTypes.bool,

  /**
   * *(Apple TV only)* Object with properties to control Apple TV parallax effects.
   *
   * enabled: If true, parallax effects are enabled.  Defaults to true.
   * shiftDistanceX: Defaults to 2.0.
   * shiftDistanceY: Defaults to 2.0.
   * tiltAngle: Defaults to 0.05.
   * magnification: Defaults to 1.0.
   * pressMagnification: Defaults to 1.0.
   * pressDuration: Defaults to 0.3.
   * pressDelay: Defaults to 0.0.
   *
   * @platform ios
   */
  tvParallaxProperties: PropTypes.object,

  /**
   * *(Apple TV only)* May be used to change the appearance of the Apple TV parallax effect when this view goes in or out of focus.  Defaults to 2.0.
   *
   * @platform ios
   */
  tvParallaxShiftDistanceX: PropTypes.number,

  /**
   * *(Apple TV only)* May be used to change the appearance of the Apple TV parallax effect when this view goes in or out of focus.  Defaults to 2.0.
   *
   * @platform ios
   */
  tvParallaxShiftDistanceY: PropTypes.number,

  /**
   * *(Apple TV only)* May be used to change the appearance of the Apple TV parallax effect when this view goes in or out of focus.  Defaults to 0.05.
   *
   * @platform ios
   */
  tvParallaxTiltAngle: PropTypes.number,

  /**
   * *(Apple TV only)* May be used to change the appearance of the Apple TV parallax effect when this view goes in or out of focus.  Defaults to 1.0.
   *
   * @platform ios
   */
  tvParallaxMagnification: PropTypes.number,
};

export type TVViewProps = $ReadOnly<{|
  isTVSelectable?: boolean,
  hasTVPreferredFocus?: boolean,
  tvParallaxProperties?: Object,
  tvParallaxShiftDistanceX?: number,
  tvParallaxShiftDistanceY?: number,
  tvParallaxTiltAngle?: number,
  tvParallaxMagnification?: number,
|}>;

module.exports = TVViewPropTypes;

==> react-native-0.58.0-rc.1.tgz: package/Libraries/Components/AppleTV/TVViewPropTypes.js <==
/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 * @flow
 */

'use strict';

export type TVParallaxPropertiesType = $ReadOnly<{|
  /**
   * If true, parallax effects are enabled.  Defaults to true.
   */
  enabled: boolean,

  /**
   * Defaults to 2.0.
   */
  shiftDistanceX: number,

  /**
   * Defaults to 2.0.
   */
  shiftDistanceY: number,

  /**
   * Defaults to 0.05.
   */
  tiltAngle: number,

  /**
   * Defaults to 1.0
   */
  magnification: number,
|}>;

/**
 * Additional View properties for Apple TV
 */
export type TVViewProps = $ReadOnly<{|
  /**
   * *(Apple TV only)* When set to true, this view will be focusable
   * and navigable using the Apple TV remote.
   *
   * @platform ios
   */
  isTVSelectable?: boolean,

  /**
   * *(Apple TV only)* May be set to true to force the Apple TV focus engine to move focus to this view.
   *
   * @platform ios
   */
  hasTVPreferredFocus?: boolean,

  /**
   * *(Apple TV only)* Object with properties to control Apple TV parallax effects.
   *
   * @platform ios
   */
  tvParallaxProperties?: TVParallaxPropertiesType,

  /**
   * *(Apple TV only)* May be used to change the appearance of the Apple TV parallax effect when this view goes in or out of focus.  Defaults to 2.0.
   *
   * @platform ios
   */
  tvParallaxShiftDistanceX?: number,

  /**
   * *(Apple TV only)* May be used to change the appearance of the Apple TV parallax effect when this view goes in or out of focus.  Defaults to 2.0.
   *
   * @platform ios
   */
  tvParallaxShiftDistanceY?: number,

  /**
   * *(Apple TV only)* May be used to change the appearance of the Apple TV parallax effect when this view goes in or out of focus.  Defaults to 0.05.
   *
   * @platform ios
   */
  tvParallaxTiltAngle?: number,

  /**
   * *(Apple TV only)* May be used to change the appearance of the Apple TV parallax effect when this view goes in or out of focus.  Defaults to 1.0.
   *
   * @platform ios
   */
  tvParallaxMagnification?: number,
|}>;
